@@ -487,7 +487,7 @@ export type IndexableStr = string;
 
 export type StorageType = "Full" | "Delta" | "Empty" | "Broken";
 
-export enum StorageType {Full, Delta, Empty, Broken};
+export enum StorageTypeEnum {Full, Delta, Empty, Broken};
 
 // Operation is a single unit of transormation logic
 type OperationType = "Fetch" | "Store" | "Drop" | "FakeOp";
